==> react-molecule-tabs-2.36.0.tgz: package/lib/components/MoleculeTabs.js <==
import { Children, cloneElement, isValidElement } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import useOnScreen from '@s-ui/react-hooks/lib/useOnScreen';
import { BASE_CLASS, CLASS_CONTENT, CLASS_SCROLLER, TYPES, VARIANTS } from '../config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeTabs = function MoleculeTabs(_ref) {
  var _cx;

  var _ref$autoScrollIntoVi = _ref.autoScrollIntoView,
      autoScrollIntoView = _ref$autoScrollIntoVi === void 0 ? true : _ref$autoScrollIntoVi,
      children = _ref.children,
      onChange = _ref.onChange,
      type = _ref.type,
      variant = _ref.variant;
  var className = cx(BASE_CLASS, (_cx = {}, _cx[BASE_CLASS + "--" + variant] = variant, _cx[BASE_CLASS + "--" + type] = type, _cx));
  var childrenArray = Children.toArray(children);

  var _useOnScreen = useOnScreen(),
      isIntersecting = _useOnScreen[0],
      outerRef = _useOnScreen[1];

  var extendedChildren = childrenArray.filter(function (child) {
    return /*#__PURE__*/isValidElement(child);
  }).map(function (child, index) {
    var numTab = index + 1;
    return /*#__PURE__*/cloneElement(child, {
      autoScrollIntoView: autoScrollIntoView,
      isIntersecting: isIntersecting,
      numTab: numTab,
      onChange: onChange
    });
  });
  var activeTabContent = childrenArray.reduce(function (activeContent, child) {
    if (child) {
      var _child$props = child.props,
          childrenChild = _child$props.children,
          active = _child$props.active;
      return active ? childrenChild : activeContent;
    }

    return activeContent;
  }, null);
  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [/*#__PURE__*/_jsx("ul", {
      ref: outerRef,
      className: CLASS_SCROLLER,
      children: extendedChildren
    }), activeTabContent ? /*#__PURE__*/_jsx("div", {
      className: CLASS_CONTENT,
      children: activeTabContent
    }) : null]
  });
};

MoleculeTabs.displayName = 'MoleculeTabs';
MoleculeTabs.defaultProps = {
  variant: VARIANTS.CLASSIC,
  type: TYPES.HORIZONTAL,
  onChange: function onChange() {}
};
export default MoleculeTabs;

==> react-molecule-tabs-2.37.0.tgz: package/lib/components/MoleculeTabs.js <==
import { Children, cloneElement, isValidElement } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import useOnScreen from '@s-ui/react-hooks/lib/useOnScreen';
import { BASE_CLASS, CLASS_CONTENT, CLASS_SCROLLER, TYPES, VARIANTS } from '../config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeTabs = function MoleculeTabs(_ref) {
  var _cx;
  var _ref$autoScrollIntoVi = _ref.autoScrollIntoView,
    autoScrollIntoView = _ref$autoScrollIntoVi === void 0 ? true : _ref$autoScrollIntoVi,
    children = _ref.children,
    _ref$id = _ref.id,
    id = _ref$id === void 0 ? 'molecule-tab-content' : _ref$id,
    onChange = _ref.onChange,
    type = _ref.type,
    variant = _ref.variant;
  var className = cx(BASE_CLASS, (_cx = {}, _cx[BASE_CLASS + "--" + variant] = variant, _cx[BASE_CLASS + "--" + type] = type, _cx));
  var childrenArray = Children.toArray(children);
  var isVerticalOrientation = type === TYPES.VERTICAL;
  var _useOnScreen = useOnScreen(),
    isIntersecting = _useOnScreen[0],
    outerRef = _useOnScreen[1];
  var extendedChildren = childrenArray.filter(function (child) {
    return /*#__PURE__*/isValidElement(child);
  }).map(function (child, index) {
    var numTab = index + 1;
    return /*#__PURE__*/cloneElement(child, {
      autoScrollIntoView: autoScrollIntoView,
      isIntersecting: isIntersecting,
      numTab: numTab,
      id: id,
      onChange: onChange
    });
  });
  var activeTabContent = childrenArray.reduce(function (activeContent, child) {
    if (child) {
      var _child$props = child.props,
        childrenChild = _child$props.children,
        active = _child$props.active,
        numTab = _child$props.numTab;
      if (active) {
        return /*#__PURE__*/_jsx("div", {
          className: CLASS_CONTENT,
          id: id + "-" + numTab,
          role: "tabpanel",
          children: childrenChild
        });
      }
    }
    return activeContent;
  }, null);
  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [/*#__PURE__*/_jsx("ul", {
      ref: outerRef,
      className: CLASS_SCROLLER,
      role: "tablist",
      "aria-orientation": isVerticalOrientation ? TYPES.VERTICAL : TYPES.HORIZONTAL,
      children: extendedChildren
    }), activeTabContent]
  });
};
MoleculeTabs.displayName = 'MoleculeTabs';
MoleculeTabs.defaultProps = {
  variant: VARIANTS.CLASSIC,
  type: TYPES.HORIZONTAL,
  onChange: function onChange() {}
};
export default MoleculeTabs;
